==> mysql-community_8.2.0.orig.tar.gz: mysql-8.2.0/sql/command_mapping.h <==
/* Copyright (c) 2022, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef SQL_COMMAND_MAPPING_H
#define SQL_COMMAND_MAPPING_H

#include "my_command.h"
#include "my_sqlcommand.h"

void init_command_maps();
void denit_command_maps();

const char *get_server_command_string(enum_server_command server_command);
enum_server_command get_server_command(const char *server_command);

const char *get_sql_command_string(enum_sql_command sql_command);

#endif  // !SQL_COMMAND_MAPPING_H

==> mysql-community_8.4.3.orig.tar.gz: mysql-8.4.3/sql/command_mapping.h <==
/* Copyright (c) 2022, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef SQL_COMMAND_MAPPING_H
#define SQL_COMMAND_MAPPING_H

#include "my_command.h"
#include "my_sqlcommand.h"

void init_command_maps();
void denit_command_maps();

const char *get_server_command_string(enum_server_command server_command);
enum_server_command get_server_command(const char *server_command);

const char *get_sql_command_string(enum_sql_command sql_command);

#endif  // !SQL_COMMAND_MAPPING_H
